@@ -42,14 +42,14 @@ typedef struct _NetstatusIconPrivate NetstatusIconPrivate;
 
 struct _NetstatusIcon
 {
-  GtkEventBox            window_instance;
+  GtkBox                 box_instance;
 
   NetstatusIconPrivate  *priv;
 };
 
 struct _NetstatusIconClass
 {
-  GtkWindowClass   window_class;
+  GtkBoxClass      box_class;
 
   void (*invoked) (NetstatusIcon *icon);
 };
@@ -72,6 +72,10 @@ void            netstatus_icon_set_tooltips_enabled (NetstatusIcon  *icon,
 						     gboolean        enabled);
 gboolean        netstatus_icon_get_tooltips_enabled (NetstatusIcon  *icon);
 
+void            netstatus_icon_set_show_signal      (NetstatusIcon  *icon,
+						     gboolean        show_signal);
+gboolean        netstatus_icon_get_show_signal      (NetstatusIcon  *icon);
+
 G_END_DECLS
 
 #endif /* __NETSTATUS_ICON_H__ */
