@@ -33,6 +33,7 @@
 
 #include <libgnome/gnome-i18n.h>
 
+#include <sys/types.h>
 #include <sys/ioctl.h>
 #ifdef HAVE_SYS_SOCKIO_H
 #include <sys/sockio.h>
@@ -41,6 +42,7 @@
 #include <sys/socket.h>
 #include <net/if.h>
 #include <net/if_arp.h>
+#include <netinet/in.h>
 #include <arpa/inet.h>
 #include <errno.h>
 #include <unistd.h>
@@ -451,10 +453,10 @@ netstatus_iface_get_sockfd (NetstatusIface *iface)
 
 static gboolean
 netstatus_iface_poll_iface_statistics (NetstatusIface *iface,
-				       long           *in_packets,
-				       long           *out_packets,
-				       long           *in_bytes,
-				       long           *out_bytes)
+				       gulong         *in_packets,
+				       gulong         *out_packets,
+				       gulong         *in_bytes,
+				       gulong         *out_bytes)
 {
   char *error_message;
 
@@ -485,8 +487,8 @@ netstatus_iface_poll_state (NetstatusIface *iface)
   struct ifreq   if_req;
   gboolean       tx, rx;
   int            fd;
-  long           in_packets, out_packets;
-  long           in_bytes, out_bytes;
+  gulong         in_packets, out_packets;
+  gulong         in_bytes, out_bytes;
 
   if (!(fd = netstatus_iface_get_sockfd (iface)))
     return NETSTATUS_STATE_DISCONNECTED;
@@ -517,10 +519,10 @@ netstatus_iface_poll_state (NetstatusIface *iface)
 
   dprintf (POLLING, "Packets in: %ld out: %ld. Prev in: %ld out: %ld\n",
 	   in_packets, out_packets,
-	   iface->priv->in_packets, iface->priv->out_packets);
+	   iface->priv->stats.in_packets, iface->priv->stats.out_packets);
   dprintf (POLLING, "Bytes in: %ld out: %ld. Prev in: %ld out: %ld\n",
 	   in_bytes, out_bytes,
-	   iface->priv->in_bytes, iface->priv->out_bytes);
+	   iface->priv->stats.in_bytes, iface->priv->stats.out_bytes);
   
   rx = in_packets  > iface->priv->stats.in_packets;
   tx = out_packets > iface->priv->stats.out_packets;
@@ -751,7 +753,7 @@ netstatus_iface_get_inet4_details (NetstatusIface  *iface,
 }
 
 static char *
-print_mac_addr (guchar *p)
+print_mac_addr (gchar *p)
 {
   return g_strdup_printf ("%02X:%02X:%02X:%02X:%02X:%02X",
 			  p [0] & 0377,
@@ -763,7 +765,7 @@ print_mac_addr (guchar *p)
 }
 
 static char *
-print_ash_addr (guchar *p)
+print_ash_addr (gchar *p)
 {
 #define ASH_ALEN 64
 
@@ -787,7 +789,7 @@ print_ash_addr (guchar *p)
 }
 
 static char *
-print_ax25_addr (guchar *p)
+print_ax25_addr (gchar *p)
 {
   GString *str;
   char    *retval;
@@ -821,37 +823,37 @@ print_ax25_addr (guchar *p)
 }
 
 static char *
-print_rose_addr (guchar *p)
+print_rose_addr (gchar *p)
 {
   return g_strdup_printf ("%02x%02x%02x%02x%02x", p [0], p [1], p [2], p [3], p [4]);
 }
 
 static char *
-print_x25_addr (guchar *p)
+print_x25_addr (gchar *p)
 {
   return g_strdup (p);
 }
 
 static char *
-print_arcnet_addr (guchar *p)
+print_arcnet_addr (gchar *p)
 {
   return g_strdup_printf ("%02X", p [0] & 0377);
 }
 
 static char *
-print_dlci_addr (guchar *p)
+print_dlci_addr (gchar *p)
 {
   return g_strdup_printf ("%i", *(short *) p);
 }
 
 static char *
-print_irda_addr (guchar *p)
+print_irda_addr (gchar *p)
 {
   return g_strdup_printf ("%02x:%02x:%02x:%02x", p [3], p [2], p [1], p [0]);
 }
 
 static char *
-print_econet_addr (guchar *p)
+print_econet_addr (gchar *p)
 {
   /* This should really be:
    *   #include <neteconet/ec.h>
@@ -868,7 +870,7 @@ static struct HwType
 {
   int   hw_type;
   char *hw_name;
-  char *(*print_hw_addr) (guchar *p);
+  char *(*print_hw_addr) (gchar *p);
 } hw_types [] =
   {
 #ifdef ARPHRD_NETROM
